#!/bin/sh
echo 'name: hashable
version: 1.1.2.3
id: hashable-1.1.2.3-d030b9fe5b35dcb16975530055dde91a

license: BSD3
copyright:
maintainer: johan.tibell@gmail.com
stability: Provisional
homepage: http://github.com/tibbe/hashable
package-url:
synopsis: A class for types that can be converted to a hash value
description: This package defines a class, '\''Hashable'\'', for types that
             can be converted to a hash value.  This class
             exists for the benefit of hashing-based data
             structures.  The package provides instances for
             basic types and a way to combine hash values.
category: Data
author: Milan Straka <fox@ucw.cz>
        Johan Tibell <johan.tibell@gmail.com>
pkgpath: devel/hs-hashable
exposed: True
exposed-modules: Data.Hashable
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/hashable-1.1.2.3
library-dirs: /usr/local/lib/ghc/hashable-1.1.2.3
hs-libraries: HShashable-1.1.2.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
         ghc-prim-0.2.0.0-7d3c2c69a5e8257a04b2c679c40e2fa7
         text-0.11.2.3-0a507fb72e97feed1b44644051bc0e5f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-hashable-1.1.2.3/html/hashable.haddock
haddock-html: /usr/local/share/doc/hs-hashable-1.1.2.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
